#!/bin/bash
# Copyright (c) 2006 Red Hat, Inc. All rights reserved. This copyrighted material 
# is made available to anyone wishing to use, modify, copy, or 
# redistribute it subject to the terms and conditions of the GNU General 
# Public License v.2.
# 
# This program is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
# PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
#
# Author: Dave Malcolm

cat PURPOSE

TEMP_DIR=`mktemp -d`
echo "TEMP_DIR=$TEMP_DIR"

TEST_PACKAGE_NAME=foobarbaz 

echo Assembling sources:
SOURCE_DIR=$TEMP_DIR/$TEST_PACKAGE_NAME
echo "SOURCE_DIR=$SOURCE_DIR"
mkdir -p $SOURCE_DIR || exit $?

echo Making specfile:
cat > $SOURCE_DIR/$TEST_PACKAGE_NAME.spec <<EOF
Summary:        Test package
Name:           $TEST_PACKAGE_NAME
Version:        1.0
Release: 	1
Group:          System Environment/Base
License:        GPL
Buildroot:      %{_tmppath}/%{name}-%{version}-root
BuildArch: noarch

%description
Dummy package

%prep

%build
[ "$RPM_BUILD_ROOT" != "/" ] && [ -d $RPM_BUILD_ROOT ] && rm -rf $RPM_BUILD_ROOT;


%install

%clean
[ "$RPM_BUILD_ROOT" != "/" ] && [ -d $RPM_BUILD_ROOT ] && rm -rf $RPM_BUILD_ROOT;


%files
%defattr(-,root,root)

%changelog
* Thu Sep 21 2006	Dave Malcolm <dmalcolm@redhat.com>
initial version
EOF

echo "**** Start of specfile ****"
cat $SOURCE_DIR/$TEST_PACKAGE_NAME.spec || exit $?
echo "**** End of specfile ****"


echo Creating tarball:
tar -czf $TEMP_DIR/test.tar.gz $SOURCE_DIR || exit $?
echo Tarball is $TEMP_DIR/test.tar.gz

BUILD_TOPDIR=$TEMP_DIR/rpmbuild
echo Making rpmbuild directory structure in $BUILD_TOPDIR
mkdir -p $BUILD_TOPDIR/BUILD   || exit $?
mkdir -p $BUILD_TOPDIR/SOURCES || exit $?
mkdir -p $BUILD_TOPDIR/SRPMS   || exit $?
mkdir -p $BUILD_TOPDIR/RPMS    || exit $?
mkdir -p $BUILD_TOPDIR/SPECS   || exit $?

echo Running rpmbuild:
echo "If RH bug 206841 is present, expect to see a series of error lines complaining about missing fields"
echo "**** Start of rpmbuild log ****"
rpmbuild --define _topdir$BUILD_TOPDIR -ta $TEMP_DIR/test.tar.gz || exit $?
echo "**** End of rpmbuild log ****"
# The bug would lead to these error lines:
# error: Name field must be present in package: (main package)"
# error: Version field must be present in package: (main package)
# error: Release field must be present in package: (main package)
# error: Summary field must be present in package: (main package)
# error: Group field must be present in package: (main package)
# error: License field must be present in package: (main package)

echo "rpmbuild exiting with 0 exit code"

BUILT_RPM=$BUILD_TOPDIR/RPMS/noarch/$TEST_PACKAGE_NAME-1.0-1.noarch.rpm
BUILT_SRPM=$BUILD_TOPDIR/SRPMS/$TEST_PACKAGE_NAME-1.0-1.src.rpm

echo "**** Verifying built RPM: $BUILT_RPM ****"
echo "Attempting to query package metadata:"
rpm -qpi $BUILT_RPM || exit $?

# Irritatingly rpm -qp returns exit code 0 when it fails to open a file, so we do some doublechecking:
ls $BUILT_RPM || exit $?
rpm -qpi $BUILT_RPM | grep "Name        : $TEST_PACKAGE_NAME" | exit $?
echo
echo "**** built RPM appears to be correct ****"
echo
echo "**** Verifying built SRPM: $BUILT_SRPM ****"
echo "Attempting to query package metadata:"
rpm -qpi $BUILT_SRPM || exit $?

# Irritatingly rpm -qp returns exit code 0 when it fails to open a file, so we do some doublechecking:
ls $BUILT_SRPM || exit $?
rpm -qpi $BUILT_SRPM | grep "Name        : $TEST_PACKAGE_NAME" | exit $?
echo
echo "**** built SRPM appears to be correct ****"

echo "Success - the RPM/SRPM appear to have been built successfully"
exit 0
